@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: sandi
 version: 0.3.6
-id: sandi-0.3.6-8ad04c1b87ad23f7840d19dbd0642a7c
-key: sandi_KLswb1xnZ4R6WQqzcUNQ7c
+id: sandi-0.3.6-9934f59507439c9a12add8a85dd87d76
+key: sandi_7atdf2uMGJLLOuQQD1Au0t
 license: BSD3
 copyright: Magnus Therning, 2012
 maintainer: magnus@therning.org
@@ -28,11 +28,11 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/sandi-0.3.6
 library-dirs: /usr/lib/ghc-7.10.3/site-local/sandi-0.3.6
 data-dir: /usr/share/arm-linux-ghc-7.10.3/sandi-0.3.6
-hs-libraries: HSsandi-0.3.6-KLswb1xnZ4R6WQqzcUNQ7c
+hs-libraries: HSsandi-0.3.6-7atdf2uMGJLLOuQQD1Au0t
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    conduit-1.2.6.4-0dfd87f475e845002478c37d3a30df1e
+    conduit-1.2.6.4-9cbf21b79aba616188d311eceb1fecef
     exceptions-0.8.2.1-8c1fe53cd5846ab1f6d4c58870c4f8d9
 haddock-interfaces: /usr/share/doc/haskell-sandi/html/sandi.haddock
 haddock-html: /usr/share/doc/haskell-sandi/html
